==> 0.0.7.tar.gz: lib/parts/manager_map.dart <==
part of aargul_crud;

extension ExtensionAargulCrudManagerMap on AargulCrudManager {
  Widget map({
    required Marker Function(Map<String, dynamic> values) itemBuilder,
    LatLng? center,
    void Function(MapController mapController)? onReady,
    Uri? tileLayerUrl,
    String? tileLayerUserAgent,
    TileProvider? tileLayerProvider,
    Map<String, String>? tileLayerOptions,
    TextSourceAttribution? attribution,
    List<Widget>? children,
  }) {
    return _Map(
      itemBuilder: itemBuilder,
      options: options,
      center: center,
      onReady: onReady,
      tileLayerUrl: tileLayerUrl,
      tileLayerUserAgent: tileLayerUserAgent,
      tileLayerProvider: tileLayerProvider,
      tileLayerOptions: tileLayerOptions,
      attribution: attribution,
      children: children,
    );
  }
}

class _Map extends StatefulWidget {
  final Marker Function(Map<String, dynamic> values) itemBuilder;
  final AargulCrudOptions options;
  final LatLng? center;
  final void Function(MapController mapController)? onReady;
  final Uri? tileLayerUrl;
  final String? tileLayerUserAgent;
  final TileProvider? tileLayerProvider;
  final Map<String, String>? tileLayerOptions;
  final TextSourceAttribution? attribution;
  final List<Widget>? children;
  final double minimumSearchDistanceDifferenceInKm;

  const _Map({
    Key? key,
    required this.options,
    required this.itemBuilder,
    this.center,
    this.onReady,
    this.tileLayerUrl,
    this.tileLayerUserAgent,
    this.tileLayerProvider,
    this.tileLayerOptions,
    this.attribution,
    this.children,
    double minimumDistanceDifferenceForSearchInKm = 10,
  })  : minimumSearchDistanceDifferenceInKm =
            minimumDistanceDifferenceForSearchInKm,
        super(key: key);

  @override
  State<_Map> createState() => __MapState();
}

class __MapState extends State<_Map> with TickerProviderStateMixin {
  late final RadiusClusterController _radiusClusterController;
  late final AnimatedMapController _animatedMapController;
  final double _raduisSearch = 100;
  static final points = <Map<String, dynamic>>[];
  late List<Marker> markers;

  @override
  void initState() {
    super.initState();
    _radiusClusterController = RadiusClusterController();
    _animatedMapController = AnimatedMapController(vsync: this);
    _search(_raduisSearch, widget.center ?? LatLng(50.5, 30.51));
  }

  @override
  void dispose() {
    _animatedMapController.dispose();
    _radiusClusterController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FlutterMap(
      mapController: _animatedMapController,
      options: MapOptions(
          center: widget.center,
          onMapReady: () {
            widget.onReady?.call(_animatedMapController);
          }),
      nonRotatedChildren: [
        if (widget.attribution != null) widget.attribution!,
        if (widget.children != null) ...widget.children!
      ],
      children: <Widget>[
        TileLayer(
          tileProvider: widget.tileLayerProvider,
          additionalOptions: widget.tileLayerOptions,
          urlTemplate: widget.tileLayerUrl?.toString() ??
              'https://tiles.stadiamaps.com/tiles/stamen_toner/{z}/{x}/{y}{r}.png',
          userAgentPackageName: widget.tileLayerUserAgent ?? 'aargul_crud',
          fallbackUrl: 'https://tile.openstreetmap.org/{z}/{x}/{y}.png',
        ),
        RadiusClusterLayer(
          controller: _radiusClusterController,
          radiusInKm: _raduisSearch,
          search: _search,
          initialCenter: widget.center,
          minimumSearchDistanceDifferenceInKm:
              widget.minimumSearchDistanceDifferenceInKm,
          moveMap: (center, zoom) => _animatedMapController.animateTo(
            dest: center,
            zoom: zoom,
          ),
          clusterWidgetSize: const Size(40, 40),
          popupOptions: PopupOptions(
            popupDisplayOptions: PopupDisplayOptions(
              builder: (context, marker) {
                return Container(
                  color: Colors.white,
                  width: 200,
                  height: 100,
                  child: Text('Popup for marker at: ${marker.point}'),
                );
              },
            ),
            selectedMarkerBuilder: (context, marker) => Icon(
              FluentIcons.pin,
              color: Colors.red,
            ),
          ),
          clusterBuilder: (context, clusterData) => Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(20.0),
              color: Colors.blue,
            ),
            child: Center(
              child: Text(
                (clusterData as ClusterDataWithCount).markerCount.toString(),
                style: const TextStyle(color: Colors.white),
              ),
            ),
          ),
        ),
      ],
    );
  }

  Future<SuperclusterImmutable<Marker>> _search(
      double radiusInKm, LatLng center) async {
    var res = await widget.options.geoRead?.call(radiusInKm, center);
    List<Map<String, dynamic>> resultPoints = res?.rows ?? [];
    setState(() {
      points.clear();
      points.addAll(resultPoints);
    });
    return SuperclusterImmutable<Marker>(
      getX: (m) => m.point.longitude,
      getY: (m) => m.point.latitude,
      extractClusterData: (marker) => ClusterDataWithCount(marker),
      radius: 80,
      maxZoom: 15,
    )..load((points).map(widget.itemBuilder).toList());
  }
}

==> 0.0.12.tar.gz: lib/parts/manager_map.dart <==
part of aargul_crud;

extension ExtensionAargulCrudManagerMap on AargulCrudManager {
  Widget map({
    required Marker Function(Map<String, dynamic> values) markerBuilder,
    LatLng? center,
    void Function(MapController mapController)? onReady,
    String? tileLayerUrl,
    List<String>? tileLayerSubdomains,
    String? tileLayerUserAgent,
    TileProvider? tileLayerProvider,
    Map<String, String>? tileLayerOptions,
    TextSourceAttribution? attribution,
    List<Widget>? children,
    TileLayer? tileLayer,
    double? minimumDistanceDifferenceForSearchInKm
  }) {
    return _Map(
      options: options,
      markerBuilder: markerBuilder,
      center: center,
      onReady: onReady,
      tileLayer: tileLayer,
      tileLayerSubdomains : tileLayerSubdomains,
      tileLayerUrl: tileLayerUrl,
      tileLayerUserAgent: tileLayerUserAgent,
      tileLayerProvider: tileLayerProvider,
      tileLayerOptions: tileLayerOptions,
      attribution: attribution,
      minimumDistanceDifferenceForSearchInKm: minimumDistanceDifferenceForSearchInKm ?? 10,
      children: children,
    );
  }
}

class _Map extends StatefulWidget {
  final Marker Function(Map<String, dynamic> values) markerBuilder;
  final AargulCrudOptions options;
  final LatLng? center;
  final void Function(MapController mapController)? onReady;
  final String? tileLayerUrl;
  final String? tileLayerUserAgent;
  final TileLayer? tileLayer;
  final List<String>? tileLayerSubdomains;
  final TileProvider? tileLayerProvider;
  final Map<String, String>? tileLayerOptions;
  final TextSourceAttribution? attribution;
  final List<Widget>? children;
  final double minimumSearchDistanceDifferenceInKm;

  const _Map({
    Key? key,
    required this.options,
    required this.markerBuilder,
    this.center,
    this.onReady,
    this.tileLayer,
    this.tileLayerSubdomains,
    this.tileLayerUrl,
    this.tileLayerUserAgent,
    this.tileLayerProvider,
    this.tileLayerOptions,
    this.attribution,
    this.children,
    double minimumDistanceDifferenceForSearchInKm = 10,
  })  : minimumSearchDistanceDifferenceInKm =
            minimumDistanceDifferenceForSearchInKm,
        super(key: key);

  @override
  State<_Map> createState() => __MapState();
}

class __MapState extends State<_Map> with TickerProviderStateMixin {
  late final RadiusClusterController _radiusClusterController;
  late final AnimatedMapController _animatedMapController;
  final double _raduisSearch = 100;
  static final points = <Map<String, dynamic>>[];
  late List<Marker> markers;

  @override
  void initState() {
    super.initState();
    _radiusClusterController = RadiusClusterController();
    _animatedMapController = AnimatedMapController(vsync: this);
    _search(_raduisSearch, widget.center ?? LatLng(50.5, 30.51));
  }

  @override
  void dispose() {
    _animatedMapController.dispose();
    _radiusClusterController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return FlutterMap(
      mapController: _animatedMapController,
      options: MapOptions(
        center: widget.center,
        onMapReady: () {
          widget.onReady?.call(_animatedMapController);
        },
      ),
      nonRotatedChildren: [
        if (widget.attribution != null) widget.attribution!,
        if (widget.children != null) ...widget.children!
      ],
      children: <Widget>[
        widget.tileLayer ??
            TileLayer(
              subdomains: widget.tileLayerSubdomains ?? const <String>[],
              tileProvider: widget.tileLayerProvider,
              additionalOptions: widget.tileLayerOptions,
              urlTemplate: widget.tileLayerUrl?.toString() ??
                  'https://tiles.stadiamaps.com/tiles/stamen_toner/{z}/{x}/{y}{r}.png',
              userAgentPackageName: widget.tileLayerUserAgent ?? 'aargul_crud',
              fallbackUrl: 'https://tile.openstreetmap.org/{z}/{x}/{y}.png',
            ),
        RadiusClusterLayer(
          controller: _radiusClusterController,
          radiusInKm: _raduisSearch,
          search: _search,
          initialCenter: widget.center,
          minimumSearchDistanceDifferenceInKm:
              widget.minimumSearchDistanceDifferenceInKm,
          moveMap: (center, zoom) => _animatedMapController.animateTo(
            dest: center,
            zoom: zoom,
          ),
          clusterWidgetSize: const Size(40, 40),
          popupOptions: PopupOptions(
            popupDisplayOptions: PopupDisplayOptions(
              builder: (context, marker) {
                return Container(
                  color: Colors.white,
                  width: 200,
                  height: 100,
                  child: Text('Popup for marker at: ${marker.point}'),
                );
              },
            ),
            selectedMarkerBuilder: (context, marker) => const Icon(
              Icons.pin,
              color: Colors.red,
            ),
          ),
          clusterBuilder: (context, clusterData) => Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(20.0),
              color: Colors.blue,
            ),
            child: Center(
              child: Text(
                (clusterData as ClusterDataWithCount).markerCount.toString(),
                style: const TextStyle(color: Colors.white),
              ),
            ),
          ),
        ),
      ],
    );
  }

  Future<SuperclusterImmutable<Marker>> _search(
      double radiusInKm, LatLng center) async {
    var res = await widget.options.geoRead?.call(radiusInKm, center);
    List<Map<String, dynamic>> resultPoints = res?.rows ?? [];
    setState(() {
      points.clear();
      points.addAll(resultPoints);
    });
    return SuperclusterImmutable<Marker>(
      getX: (m) => m.point.longitude,
      getY: (m) => m.point.latitude,
      extractClusterData: (marker) => ClusterDataWithCount(marker),
      radius: 80,
      maxZoom: 15,
    )..load((points).map(widget.markerBuilder).toList());
  }
}
